/// <reference types="node" />
export declare function getBufferClass(): BufferConstructor;
export declare enum Endian {
    LE = 0,
    BE = 1
}
export declare function createReader(endianness: Endian, buffer: Buffer): IReader;
export declare function createWriter(endianness: Endian, size?: number): IWriter;
export interface IReader {
    readBuffer(bytes: number): Buffer;
    readUint8Array(bytes: number): Uint8Array;
    readByte(): number;
    readUByte(): number;
    readBool(): boolean;
    readShort(): number;
    readUShort(): number;
    readInt(): number;
    readUInt(): number;
    readLong(): bigint;
    readULong(): bigint;
    readFloat(): number;
    readDouble(): number;
    readShortString(): string;
    readString(): string;
    readString16(): string;
}
export interface IWriter {
    toBuffer(): Buffer;
    toString(): string;
    writeBuffer(buffer: Buffer): IWriter;
    writeUint8Array(array: Uint8Array): IWriter;
    writeByte(value: number): IWriter;
    writeUByte(value: number): IWriter;
    writeBool(value: boolean | number): IWriter;
    writeShort(value: number): IWriter;
    writeUShort(value: number): IWriter;
    writeInt(value: number): IWriter;
    writeUInt(value: number): IWriter;
    writeLong(value: number | bigint): IWriter;
    writeULong(value: number): IWriter;
    writeFloat(value: number): IWriter;
    writeDouble(value: number): IWriter;
    writeShortString(text: string): IWriter;
    writeString(text: string): IWriter;
    writeString16(text: string): IWriter;
}
